recordedDuration property
How long the running recording has been going, for an on-screen timer. Resets to zero when recording stops.
Implementation
@override
ValueListenable<Duration> get recordedDuration => _recordedDuration;
How long the running recording has been going, for an on-screen timer. Resets to zero when recording stops.
@override
ValueListenable<Duration> get recordedDuration => _recordedDuration;