install method
void
install()
Installs this as the platform and restores the default on teardown.
Implementation
void install() => MonolensPlatform.instance = this;
Installs this as the platform and restores the default on teardown.
void install() => MonolensPlatform.instance = this;