FakeMediaPicker class
A MediaPicker that returns canned media, or null for a cancelled pick.
- Implemented types
Constructors
- FakeMediaPicker({CapturedImage? image, CapturedVideo? video})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image ↔ CapturedImage?
-
getter/setter pair
- imagePickCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- video ↔ CapturedVideo?
-
getter/setter pair
- videoPickCount ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickImage(
) → Future< CapturedImage?> -
Picks one image. Null if the author cancelled.
override
-
pickVideo(
) → Future< CapturedVideo?> -
Picks one video. Null if the author cancelled.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited